# Calculating Scores from Numeric Fields and Updating Custom Fact Sheet Fields
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#prerequisites)
  * [Step 1: Create Custom Fact Sheet Fields](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#step-1:-create-custom-fact-sheet-fields)
  * [Step 2: Map Risk Scores to Risk Tiers](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#step-2:-map-risk-scores-to-risk-tiers)
  * [Step 3: Configure a Connector](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#step-3:-configure-a-connector)
  * [Summary](https://help.sap.com/docs/leanix/ea/calculating-scores-from-numeric-fields-and-updating-custom-fact-sheet-fields#summary)


Learn how to set up a custom calculation using the inboundFactSheet processor of the Integration API. The processor calculates risk scores from numeric fields and writes the calculated score and mapped risk tier to custom fact sheet fields.
